@@ -9,25 +9,25 @@ class AccessibilityActor(Actor):
         super().__init__(*args, **kwargs)
 
     def get_traits(self):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "getTraits",
         }, "traits")
     
     def bootstrap(self):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "bootstrap",
         }, "state")
 
     def get_walker(self):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "getWalker",
         }, "walker")
 
     def get_simulator(self):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "getSimulator",
         }, "simulator")
